import ArtistInfoBox from "@/components/images/ArtistInfoBox";
import GlowingImageWithToggle from "@/components/images/GlowingImageWithToggle";
import ImageMetadataBox from "@/components/images/ImageMetadataBox";
import prisma from "@/lib/prisma";

export default async function ImagePage({ params }: { params: { gallerySlug: string, albumSlug: string, imageId: string } }) {
  const { imageId } = await params;

  const image = await prisma.image.findUnique({
    where: {
      id: imageId
    },
    include: {
      artist: { include: { socials: true } },
      colors: { include: { color: true } },
      extractColors: { include: { extract: true } },
      palettes: { include: { palette: { include: { items: true } } } },
      album: true,
      categories: true,
      tags: true,
      variants: true,
      metadata: true,
      stats: true
    }
  })

  if (!image) return <div>Image not found</div>

  const resizedVariant = image.variants.find(v => v.type === "resized");

  return (
    <div>
      {image && (
        <div className="flex flex-col items-center">
          <div>
            <h1 className="text-2xl font-bold mb-4 pb-8">{image.imageName}</h1>
          </div>

          {resizedVariant &&
            <GlowingImageWithToggle
              alt={image.imageName}
              variant={resizedVariant}
              colors={image.colors}
              src={`/api/image/${resizedVariant.s3Key}`}
            />
          }
          <div className="py-8 flex flex-col gap-4">
            {image.artist && <ArtistInfoBox artist={image.artist} />}

            <ImageMetadataBox
              album={image.album}
              categories={image.categories}
              tags={image.tags}
            />
          </div>
        </div>
      )}
    </div >
  );
}