"use client"

import { Color, ImageColor, ImageVariant } from "@/generated/prisma"
import clsx from "clsx"
import { useTheme } from "next-themes"
import NextImage from "next/image"
import { useEffect, useState } from "react"

type Colors = ImageColor & {
  color: Color
}

type Props = {
  alt: string,
  variant: ImageVariant,
  colors: Colors[],
  src: string
  className?: string
  animate?: boolean
}

export default function GlowingImageBorder({
  alt,
  variant,
  colors,
  src,
  className,
  animate = true,
}: Props) {
  const { resolvedTheme } = useTheme()
  const [mounted, setMounted] = useState(false);

  useEffect(() => {
    setMounted(true);
  }, []);

  const getColor = (type: string) =>
    colors.find((c) => c.type === type)?.color.hex

  const vibrantLight = getColor("vibrant") || "#ff5ec4"
  const mutedLight = getColor("muted") || "#5ecaff"

  const darkVibrant = getColor("darkVibrant") || "#fc03a1"
  const darkMuted = getColor("darkMuted") || "#035efc"

  const vibrant = resolvedTheme === "dark" ? darkVibrant : vibrantLight
  const muted = resolvedTheme === "dark" ? darkMuted : mutedLight

  if (!mounted) return null;

  return (
    <div
      className={clsx(
        "relative inline-block rounded-xl overflow-hidden p-[12px]",
        animate ? "glow-border" : "static-glow-border",
        className
      )}
      style={
        {
          "--vibrant": vibrant,
          "--muted": muted,
        } as React.CSSProperties
      }
    >
      <div className="relative z-10 rounded-xl overflow-hidden">
        <NextImage
          src={src}
          alt={alt || "Image"}
          width={variant.width}
          height={variant.height}
          className="rounded-xl"
        />
      </div>
    </div>
  )
}
